@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2021 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013-2025 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,9 @@
 
 #include "query.h"
 #include "settings.h"
-#include "util.h"
+
+#include <libxfce4ui/libxfce4ui.h>
+#include <glib/gstdio.h>
 
 using namespace WhiskerMenu;
 
@@ -52,98 +54,6 @@ static std::string normalize(const gchar* string)
 
 //-----------------------------------------------------------------------------
 
-#if !LIBXFCE4UTIL_CHECK_VERSION(4,15,2)
-static void replace_with_quoted_string(std::string& command, std::string::size_type& index, const gchar* unquoted)
-{
-	if (!xfce_str_is_empty(unquoted))
-	{
-		gchar* quoted = g_shell_quote(unquoted);
-		command.replace(index, 2, quoted);
-		index += strlen(quoted);
-		g_free(quoted);
-	}
-	else
-	{
-		command.erase(index, 2);
-	}
-}
-
-//-----------------------------------------------------------------------------
-
-static void replace_with_quoted_string(std::string& command, std::string::size_type& index, const gchar* prefix, const gchar* unquoted)
-{
-	if (!xfce_str_is_empty(unquoted))
-	{
-		command.replace(index, 2, prefix);
-		index += strlen(prefix);
-
-		gchar* quoted = g_shell_quote(unquoted);
-		command.insert(index, quoted);
-		index += strlen(quoted);
-		g_free(quoted);
-	}
-	else
-	{
-		command.erase(index, 2);
-	}
-}
-
-//-----------------------------------------------------------------------------
-
-static gchar* xfce_expand_desktop_entry_field_codes(const gchar* command, GSList* /*uri_list*/,
-		const gchar* icon, const gchar* name, const gchar* uri, gboolean requires_terminal)
-{
-	std::string expanded(command);
-
-	if (requires_terminal)
-	{
-		expanded.insert(0, "exo-open --launch TerminalEmulator ");
-	}
-
-	std::string::size_type length = expanded.length() - 1;
-	for (std::string::size_type i = 0; i < length; ++i)
-	{
-		if (G_UNLIKELY(expanded[i] == '%'))
-		{
-			switch (expanded[i + 1])
-			{
-			case 'i':
-				replace_with_quoted_string(expanded, i, "--icon ", icon);
-				break;
-
-			case 'c':
-				replace_with_quoted_string(expanded, i, name);
-				break;
-
-			case 'k':
-				replace_with_quoted_string(expanded, i, uri);
-				break;
-
-			case '%':
-				expanded.erase(i, 1);
-				break;
-
-			case 'f':
-				// unsupported, pass in a single file dropped on launcher
-			case 'F':
-				// unsupported, pass in a list of files dropped on launcher
-			case 'u':
-				// unsupported, pass in a single URL dropped on launcher
-			case 'U':
-				// unsupported, pass in a list of URLs dropped on launcher
-			default:
-				expanded.erase(i, 2);
-				break;
-			}
-			length = expanded.length() - 1;
-		}
-	}
-	return g_strdup(expanded.c_str());
-}
-#endif
-
-//-----------------------------------------------------------------------------
-
 Launcher::Launcher(GarconMenuItem* item) :
 	m_item(item),
 	m_search_flags(0)
@@ -237,6 +147,36 @@ Launcher::~Launcher()
 
 //-----------------------------------------------------------------------------
 
+bool Launcher::has_auto_start() const
+{
+	const std::string filename = std::string("autostart/") + get_desktop_id();
+
+	// Check if autostart launcher exists
+	gchar* path = xfce_resource_lookup(XFCE_RESOURCE_CONFIG, filename.c_str());
+	if (!path)
+	{
+		return false;
+	}
+	g_free(path);
+
+	// Check if launcher is hidden or invalid
+	XfceRc* rc = xfce_rc_config_open(XFCE_RESOURCE_CONFIG, filename.c_str(), true);
+	if (!rc)
+	{
+		return false;
+	}
+
+	xfce_rc_set_group(rc, "Desktop Entry");
+	const bool hidden = xfce_rc_read_bool_entry(rc, "Hidden", false);
+	const bool invalid = xfce_str_is_empty(xfce_rc_read_entry(rc, "Exec", nullptr));
+
+	xfce_rc_close(rc);
+
+	return !hidden && !invalid;
+}
+
+//-----------------------------------------------------------------------------
+
 // Adapted from https://git.xfce.org/xfce/xfce4-appfinder/tree/src/appfinder-window.c#n945
 void Launcher::hide()
 {
@@ -400,3 +340,39 @@ unsigned int Launcher::search(const Query& query)
 }
 
 //-----------------------------------------------------------------------------
+
+void Launcher::set_auto_start(bool enabled)
+{
+	// Fetch autostart path for launcher
+	const std::string filename = std::string("autostart/") + get_desktop_id();
+	gchar* path = xfce_resource_save_location(XFCE_RESOURCE_CONFIG, filename.c_str(), true);
+
+	// Always remove launcher from autostart directory
+	g_remove(path);
+
+	if (enabled)
+	{
+		// Copy launcher to autostart directory
+		GFile* source = get_file();
+		GFile* dest = g_file_new_for_path(path);
+		g_file_copy(source, dest, G_FILE_COPY_NONE, nullptr, nullptr, nullptr, nullptr);
+		g_object_unref(source);
+		g_object_unref(dest);
+	}
+	else if (has_auto_start())
+	{
+		// Disable global autostart
+		XfceRc* rc = xfce_rc_config_open(XFCE_RESOURCE_CONFIG, filename.c_str(), false);
+		if (rc)
+		{
+			xfce_rc_set_group(rc, "Desktop Entry");
+			xfce_rc_write_bool_entry(rc, "Hidden", true);
+			xfce_rc_close(rc);
+		}
+	}
+
+	// Clean up
+	g_free(path);
+}
+
+//-----------------------------------------------------------------------------
