@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2021 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013-2025 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -485,6 +485,29 @@ void Page::create_context_menu(GtkTreePath* path, GdkEvent* event)
 		});
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 
+	if (!m_selected_launcher->has_auto_start())
+	{
+		menuitem = whiskermenu_image_menu_item_new("list-add", _("Add to Autostart"));
+		connect(menuitem, "activate",
+			[this](GtkMenuItem*)
+			{
+				g_assert(m_selected_launcher);
+				m_selected_launcher->set_auto_start(true);
+			});
+		gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
+	}
+	else
+	{
+		menuitem = whiskermenu_image_menu_item_new("list-remove", _("Remove from Autostart"));
+		connect(menuitem, "activate",
+			[this](GtkMenuItem*)
+			{
+				g_assert(m_selected_launcher);
+				m_selected_launcher->set_auto_start(false);
+			});
+		gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
+	}
+
 	menuitem = gtk_separator_menu_item_new();
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 
