@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2021 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013-2025 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,9 +48,9 @@ public:
 
 	enum Position
 	{
-		PositionHorizontal = GTK_ORIENTATION_HORIZONTAL,
-		PositionVertical = GTK_ORIENTATION_VERTICAL,
-		PositionAtCursor
+		PositionAtButton,
+		PositionAtCursor,
+		PositionAtCenter
 	};
 
 	GtkWidget* get_widget() const
@@ -78,8 +78,13 @@ public:
 		return m_recent;
 	}
 
+	Page* get_active_page();
+
 	void hide(bool lost_focus = false);
 	void show(const Position position);
+	void resize(int delta_x, int delta_y, int delta_width, int delta_height);
+	void resize_start();
+	void resize_end();
 	void set_child_has_focus();
 	void set_categories(const std::vector<CategoryButton*>& categories);
 	void set_items();
@@ -87,18 +92,20 @@ public:
 	void unset_items();
 
 private:
+	GtkWidget* get_active_category_button();
 	gboolean on_key_press_event(GtkWidget* widget, GdkEventKey* key_event);
 	gboolean on_key_press_event_after(GtkWidget* widget, GdkEventKey* key_event);
 	gboolean on_map_event();
 	void on_state_flags_changed(GtkWidget* widget);
-	gboolean on_configure_event(GdkEventConfigure* configure_event);
-	gboolean on_window_state_event(GdkEventWindowState* state_event);
 	void on_screen_changed(GtkWidget* widget);
 	gboolean on_draw_event(GtkWidget* widget, cairo_t* cr);
 	void check_scrollbar_needed();
 	void favorites_toggled();
 	void recent_toggled();
 	void category_toggled();
+	void center_window();
+	void move_window();
+	bool set_size(int width, int height);
 	void reset_default_button();
 	void show_favorites();
 	void show_default_page();
@@ -123,6 +130,8 @@ private:
 	GtkStack* m_panels_stack;
 
 	Resizer* m_resize[8];
+	Position m_position;
+	GdkRectangle m_monitor;
 
 	Profile* m_profile;
 
@@ -143,15 +152,16 @@ private:
 	GtkSizeGroup* m_sidebar_size_group;
 
 	GdkRectangle m_geometry;
-	bool m_layout_left;
-	bool m_layout_bottom;
+	bool m_layout_ltr;
 	bool m_layout_categories_horizontal;
 	bool m_layout_categories_alternate;
 	bool m_layout_search_alternate;
 	bool m_layout_commands_alternate;
+	bool m_layout_profile_alternate;
 	int m_profile_shape;
 	bool m_supports_alpha;
 	bool m_child_has_focus;
+	bool m_resizing;
 };
 
 }
